@@ -5,7 +5,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"os"
 	"path/filepath"
@@ -13,6 +12,7 @@ import (
 
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/run"
 	"github.com/cli/cli/v2/pkg/cmd/release/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/httpmock"
@@ -25,7 +25,7 @@ import (
 
 func Test_NewCmdCreate(t *testing.T) {
 	tempDir := t.TempDir()
-	tf, err := ioutil.TempFile(tempDir, "release-create")
+	tf, err := os.CreateTemp(tempDir, "release-create")
 	require.NoError(t, err)
 	fmt.Fprint(tf, "MY NOTES")
 	tf.Close()
@@ -224,18 +224,18 @@ func Test_NewCmdCreate(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			io, stdin, _, _ := iostreams.Test()
+			ios, stdin, _, _ := iostreams.Test()
 			if tt.stdin == "" {
-				io.SetStdinTTY(tt.isTTY)
+				ios.SetStdinTTY(tt.isTTY)
 			} else {
-				io.SetStdinTTY(false)
+				ios.SetStdinTTY(false)
 				fmt.Fprint(stdin, tt.stdin)
 			}
-			io.SetStdoutTTY(tt.isTTY)
-			io.SetStderrTTY(tt.isTTY)
+			ios.SetStdoutTTY(tt.isTTY)
+			ios.SetStderrTTY(tt.isTTY)
 
 			f := &cmdutil.Factory{
-				IOStreams: io,
+				IOStreams: ios,
 			}
 
 			var opts *CreateOptions
@@ -250,8 +250,8 @@ func Test_NewCmdCreate(t *testing.T) {
 			cmd.SetArgs(argv)
 
 			cmd.SetIn(&bytes.Buffer{})
-			cmd.SetOut(ioutil.Discard)
-			cmd.SetErr(ioutil.Discard)
+			cmd.SetOut(io.Discard)
+			cmd.SetErr(io.Discard)
 
 			_, err = cmd.ExecuteC()
 			if tt.wantErr != "" {
@@ -286,7 +286,7 @@ func Test_createRun(t *testing.T) {
 		name       string
 		isTTY      bool
 		opts       CreateOptions
-		wantParams interface{}
+		httpStubs  func(t *testing.T, reg *httpmock.Registry)
 		wantErr    string
 		wantStdout string
 		wantStderr string
@@ -301,12 +301,20 @@ func Test_createRun(t *testing.T) {
 				BodyProvided: true,
 				Target:       "",
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":   "v1.2.3",
-				"name":       "The Big 1.2",
-				"body":       "* Fixed bugs",
-				"draft":      false,
-				"prerelease": false,
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":   "v1.2.3",
+						"name":       "The Big 1.2",
+						"body":       "* Fixed bugs",
+						"draft":      false,
+						"prerelease": false,
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 			wantStderr: ``,
@@ -322,13 +330,21 @@ func Test_createRun(t *testing.T) {
 				Target:             "",
 				DiscussionCategory: "General",
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":                 "v1.2.3",
-				"name":                     "The Big 1.2",
-				"body":                     "* Fixed bugs",
-				"draft":                    false,
-				"prerelease":               false,
-				"discussion_category_name": "General",
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":                 "v1.2.3",
+						"name":                     "The Big 1.2",
+						"body":                     "* Fixed bugs",
+						"draft":                    false,
+						"prerelease":               false,
+						"discussion_category_name": "General",
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 			wantStderr: ``,
@@ -343,11 +359,19 @@ func Test_createRun(t *testing.T) {
 				BodyProvided: true,
 				Target:       "main",
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":         "v1.2.3",
-				"draft":            false,
-				"prerelease":       false,
-				"target_commitish": "main",
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":         "v1.2.3",
+						"draft":            false,
+						"prerelease":       false,
+						"target_commitish": "main",
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 			wantStderr: ``,
@@ -363,35 +387,22 @@ func Test_createRun(t *testing.T) {
 				Draft:        true,
 				Target:       "",
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":   "v1.2.3",
-				"draft":      true,
-				"prerelease": false,
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":   "v1.2.3",
+						"draft":      true,
+						"prerelease": false,
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 			wantStderr: ``,
 		},
-		{
-			name:  "discussion category for draft release",
-			isTTY: true,
-			opts: CreateOptions{
-				TagName:            "v1.2.3",
-				Name:               "",
-				Body:               "",
-				BodyProvided:       true,
-				Draft:              true,
-				Target:             "",
-				DiscussionCategory: "general",
-			},
-			wantParams: map[string]interface{}{
-				"tag_name":                 "v1.2.3",
-				"draft":                    true,
-				"prerelease":               false,
-				"discussion_category_name": "general",
-			},
-			wantErr:    "X Discussions not supported with draft releases",
-			wantStdout: "",
-		},
 		{
 			name:  "with generate notes",
 			isTTY: true,
@@ -403,11 +414,19 @@ func Test_createRun(t *testing.T) {
 				BodyProvided:  true,
 				GenerateNotes: true,
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":               "v1.2.3",
-				"draft":                  false,
-				"prerelease":             false,
-				"generate_release_notes": true,
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":               "v1.2.3",
+						"draft":                  false,
+						"prerelease":             false,
+						"generate_release_notes": true,
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 			wantErr:    "",
@@ -426,16 +445,103 @@ func Test_createRun(t *testing.T) {
 					{
 						Name: "ball.tgz",
 						Open: func() (io.ReadCloser, error) {
-							return ioutil.NopCloser(bytes.NewBufferString(`TARBALL`)), nil
+							return io.NopCloser(bytes.NewBufferString(`TARBALL`)), nil
 						},
 					},
 				},
 				Concurrency: 1,
 			},
-			wantParams: map[string]interface{}{
-				"tag_name":   "v1.2.3",
-				"draft":      true,
-				"prerelease": false,
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":   "v1.2.3",
+						"draft":      true,
+						"prerelease": false,
+					}, params)
+				}))
+				reg.Register(httpmock.REST("POST", "assets/upload"), func(req *http.Request) (*http.Response, error) {
+					q := req.URL.Query()
+					assert.Equal(t, "ball.tgz", q.Get("name"))
+					assert.Equal(t, "", q.Get("label"))
+					return &http.Response{
+						StatusCode: 201,
+						Request:    req,
+						Body:       io.NopCloser(bytes.NewBufferString(`{}`)),
+						Header: map[string][]string{
+							"Content-Type": {"application/json"},
+						},
+					}, nil
+				})
+				reg.Register(httpmock.REST("PATCH", "releases/123"), httpmock.RESTPayload(201, `{
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3-final"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"draft": false,
+					}, params)
+				}))
+			},
+			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3-final\n",
+			wantStderr: ``,
+		},
+		{
+			name:  "upload files and create discussion",
+			isTTY: true,
+			opts: CreateOptions{
+				TagName:      "v1.2.3",
+				Name:         "",
+				Body:         "",
+				BodyProvided: true,
+				Draft:        false,
+				Target:       "",
+				Assets: []*shared.AssetForUpload{
+					{
+						Name: "ball.tgz",
+						Open: func() (io.ReadCloser, error) {
+							return io.NopCloser(bytes.NewBufferString(`TARBALL`)), nil
+						},
+					},
+				},
+				DiscussionCategory: "general",
+				Concurrency:        1,
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.RESTPayload(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"tag_name":                 "v1.2.3",
+						"draft":                    true,
+						"prerelease":               false,
+						"discussion_category_name": "general",
+					}, params)
+				}))
+				reg.Register(httpmock.REST("POST", "assets/upload"), func(req *http.Request) (*http.Response, error) {
+					q := req.URL.Query()
+					assert.Equal(t, "ball.tgz", q.Get("name"))
+					assert.Equal(t, "", q.Get("label"))
+					return &http.Response{
+						StatusCode: 201,
+						Request:    req,
+						Body:       io.NopCloser(bytes.NewBufferString(`{}`)),
+						Header: map[string][]string{
+							"Content-Type": {"application/json"},
+						},
+					}, nil
+				})
+				reg.Register(httpmock.REST("PATCH", "releases/123"), httpmock.RESTPayload(201, `{
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3-final"
+				}`, func(params map[string]interface{}) {
+					assert.Equal(t, map[string]interface{}{
+						"draft":                    false,
+						"discussion_category_name": "general",
+					}, params)
+				}))
 			},
 			wantStdout: "https://github.com/OWNER/REPO/releases/tag/v1.2.3-final\n",
 			wantStderr: ``,
@@ -443,23 +549,18 @@ func Test_createRun(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			io, _, stdout, stderr := iostreams.Test()
-			io.SetStdoutTTY(tt.isTTY)
-			io.SetStdinTTY(tt.isTTY)
-			io.SetStderrTTY(tt.isTTY)
+			ios, _, stdout, stderr := iostreams.Test()
+			ios.SetStdoutTTY(tt.isTTY)
+			ios.SetStdinTTY(tt.isTTY)
+			ios.SetStderrTTY(tt.isTTY)
 
 			fakeHTTP := &httpmock.Registry{}
-			fakeHTTP.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.StatusStringResponse(201, `{
-				"url": "https://api.github.com/releases/123",
-				"upload_url": "https://api.github.com/assets/upload",
-				"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
-			}`))
-			fakeHTTP.Register(httpmock.REST("POST", "assets/upload"), httpmock.StatusStringResponse(201, `{}`))
-			fakeHTTP.Register(httpmock.REST("PATCH", "releases/123"), httpmock.StatusStringResponse(201, `{
-				"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3-final"
-			}`))
+			if tt.httpStubs != nil {
+				tt.httpStubs(t, fakeHTTP)
+			}
+			defer fakeHTTP.Verify(t)
 
-			tt.opts.IO = io
+			tt.opts.IO = ios
 			tt.opts.HttpClient = func() (*http.Client, error) {
 				return &http.Client{Transport: fakeHTTP}, nil
 			}
@@ -475,26 +576,6 @@ func Test_createRun(t *testing.T) {
 				require.NoError(t, err)
 			}
 
-			bb, err := ioutil.ReadAll(fakeHTTP.Requests[0].Body)
-			require.NoError(t, err)
-			var params interface{}
-			err = json.Unmarshal(bb, &params)
-			require.NoError(t, err)
-			assert.Equal(t, tt.wantParams, params)
-
-			if len(tt.opts.Assets) > 0 {
-				q := fakeHTTP.Requests[1].URL.Query()
-				assert.Equal(t, tt.opts.Assets[0].Name, q.Get("name"))
-				assert.Equal(t, tt.opts.Assets[0].Label, q.Get("label"))
-
-				bb, err := ioutil.ReadAll(fakeHTTP.Requests[2].Body)
-				require.NoError(t, err)
-				var updateParams interface{}
-				err = json.Unmarshal(bb, &updateParams)
-				require.NoError(t, err)
-				assert.Equal(t, map[string]interface{}{"draft": false}, updateParams)
-			}
-
 			assert.Equal(t, tt.wantStdout, stdout.String())
 			assert.Equal(t, tt.wantStderr, stderr.String())
 		})
@@ -506,6 +587,7 @@ func Test_createRun_interactive(t *testing.T) {
 		name       string
 		httpStubs  func(*httpmock.Registry)
 		askStubs   func(*prompt.AskStubber)
+		runStubs   func(*run.CommandStubber)
 		opts       *CreateOptions
 		wantParams map[string]interface{}
 		wantOut    string
@@ -515,42 +597,34 @@ func Test_createRun_interactive(t *testing.T) {
 			name: "create a release from existing tag",
 			opts: &CreateOptions{},
 			askStubs: func(as *prompt.AskStubber) {
-				as.StubOne("v1.2.3") // Tag prompt
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "name",
-						Value: "title",
-					},
-					{
-						Name:  "releaseNotesAction",
-						Value: "Leave blank",
-					},
-				})
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "prerelease",
-						Value: false,
-					},
-					{
-						Name:  "submitAction",
-						Value: "Publish release",
-					},
-				})
+				as.StubPrompt("Choose a tag").
+					AssertOptions([]string{"v1.2.3", "v1.2.2", "v1.0.0", "v0.1.2", "Create a new tag"}).
+					AnswerWith("v1.2.3")
+				as.StubPrompt("Title (optional)").AnswerWith("")
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using generated notes as template", "Leave blank"}).
+					AnswerWith("Leave blank")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").
+					AssertOptions([]string{"Publish release", "Save as draft", "Cancel"}).AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 1, "")
 			},
 			httpStubs: func(reg *httpmock.Registry) {
 				reg.Register(httpmock.REST("GET", "repos/OWNER/REPO/tags"), httpmock.StatusStringResponse(200, `[
-            { "name": "v1.2.3" }, { "name": "v1.2.2" }, { "name": "v1.0.0" }, { "name": "v0.1.2" }
-         ]`))
+					{ "name": "v1.2.3" }, { "name": "v1.2.2" }, { "name": "v1.0.0" }, { "name": "v0.1.2" }
+				]`))
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
 					httpmock.StatusStringResponse(200, `{
-            "name": "generated name",
-            "body": "generated body"
-         }`))
+						"name": "generated name",
+						"body": "generated body"
+					}`))
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.StatusStringResponse(201, `{
-           "url": "https://api.github.com/releases/123",
-           "upload_url": "https://api.github.com/assets/upload",
-           "html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
-         }`))
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`))
 			},
 			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 		},
@@ -558,43 +632,32 @@ func Test_createRun_interactive(t *testing.T) {
 			name: "create a release from new tag",
 			opts: &CreateOptions{},
 			askStubs: func(as *prompt.AskStubber) {
-				as.StubOne("Create a new tag") // Tag prompt
-				as.StubOne("v1.2.3")           // New tag prompt
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "name",
-						Value: "title",
-					},
-					{
-						Name:  "releaseNotesAction",
-						Value: "Leave blank",
-					},
-				})
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "prerelease",
-						Value: false,
-					},
-					{
-						Name:  "submitAction",
-						Value: "Publish release",
-					},
-				})
+				as.StubPrompt("Choose a tag").AnswerWith("Create a new tag")
+				as.StubPrompt("Tag name").AnswerWith("v1.2.3")
+				as.StubPrompt("Title (optional)").AnswerWith("")
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using generated notes as template", "Leave blank"}).
+					AnswerWith("Leave blank")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 1, "")
 			},
 			httpStubs: func(reg *httpmock.Registry) {
 				reg.Register(httpmock.REST("GET", "repos/OWNER/REPO/tags"), httpmock.StatusStringResponse(200, `[
-            { "name": "v1.2.2" }, { "name": "v1.0.0" }, { "name": "v0.1.2" }
-         ]`))
+					{ "name": "v1.2.2" }, { "name": "v1.0.0" }, { "name": "v0.1.2" }
+				]`))
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
 					httpmock.StatusStringResponse(200, `{
-            "name": "generated name",
-            "body": "generated body"
-         }`))
+						"name": "generated name",
+						"body": "generated body"
+					}`))
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.StatusStringResponse(201, `{
-           "url": "https://api.github.com/releases/123",
-           "upload_url": "https://api.github.com/assets/upload",
-           "html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
-         }`))
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`))
 			},
 			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 		},
@@ -604,49 +667,162 @@ func Test_createRun_interactive(t *testing.T) {
 				TagName: "v1.2.3",
 			},
 			askStubs: func(as *prompt.AskStubber) {
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "name",
-						Value: "title",
-					},
-					{
-						Name:  "releaseNotesAction",
-						Value: "Write using generated notes as template",
-					},
-				})
-				as.Stub([]*prompt.QuestionStub{
-					{
-						Name:  "prerelease",
-						Value: false,
-					},
-					{
-						Name:  "submitAction",
-						Value: "Publish release",
-					},
-				})
+				as.StubPrompt("Title (optional)").AnswerDefault()
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using generated notes as template", "Leave blank"}).
+					AnswerWith("Write using generated notes as template")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 1, "")
 			},
 			httpStubs: func(reg *httpmock.Registry) {
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
 					httpmock.StatusStringResponse(200, `{
-            "name": "generated name",
-            "body": "generated body"
-         }`))
+						"name": "generated name",
+						"body": "generated body"
+					}`))
 				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"),
 					httpmock.StatusStringResponse(201, `{
-           "url": "https://api.github.com/releases/123",
-           "upload_url": "https://api.github.com/assets/upload",
-           "html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
-         }`))
+						"url": "https://api.github.com/releases/123",
+						"upload_url": "https://api.github.com/assets/upload",
+						"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+					}`))
 			},
 			wantParams: map[string]interface{}{
 				"body":       "generated body",
 				"draft":      false,
-				"name":       "title",
+				"name":       "generated name",
 				"prerelease": false,
 				"tag_name":   "v1.2.3",
 			},
 			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
 		},
+		{
+			name: "create a release using commit log as notes",
+			opts: &CreateOptions{
+				TagName: "v1.2.3",
+			},
+			askStubs: func(as *prompt.AskStubber) {
+				as.StubPrompt("Title (optional)").AnswerDefault()
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using commit log as template", "Leave blank"}).
+					AnswerWith("Write using commit log as template")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 1, "")
+				rs.Register(`git describe --tags --abbrev=0 HEAD\^`, 0, "v1.2.2\n")
+				rs.Register(`git .+log .+v1\.2\.2\.\.HEAD$`, 0, "commit subject\n\ncommit body\n")
+			},
+			httpStubs: func(reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
+					httpmock.StatusStringResponse(404, `{}`))
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"),
+					httpmock.StatusStringResponse(201, `{
+						"url": "https://api.github.com/releases/123",
+						"upload_url": "https://api.github.com/assets/upload",
+						"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+					}`))
+			},
+			wantParams: map[string]interface{}{
+				"body":       "* commit subject\n\n  commit body\n  ",
+				"draft":      false,
+				"prerelease": false,
+				"tag_name":   "v1.2.3",
+			},
+			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
+		},
+		{
+			name: "create using annotated tag as notes",
+			opts: &CreateOptions{
+				TagName: "v1.2.3",
+			},
+			askStubs: func(as *prompt.AskStubber) {
+				as.StubPrompt("Title (optional)").AnswerDefault()
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using git tag message as template", "Leave blank"}).
+					AnswerWith("Write using git tag message as template")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 0, "hello from annotated tag")
+				rs.Register(`git describe --tags --abbrev=0 v1\.2\.3\^`, 1, "")
+			},
+			httpStubs: func(reg *httpmock.Registry) {
+				reg.Register(httpmock.GraphQL("RepositoryFindRef"),
+					httpmock.StringResponse(`{"data":{"repository":{"ref": {"id": "tag id"}}}}`))
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
+					httpmock.StatusStringResponse(404, `{}`))
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"),
+					httpmock.StatusStringResponse(201, `{
+						"url": "https://api.github.com/releases/123",
+						"upload_url": "https://api.github.com/assets/upload",
+						"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+					}`))
+			},
+			wantParams: map[string]interface{}{
+				"body":       "hello from annotated tag",
+				"draft":      false,
+				"prerelease": false,
+				"tag_name":   "v1.2.3",
+			},
+			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
+		},
+		{
+			name: "error when unpublished local tag and target not specified",
+			opts: &CreateOptions{
+				TagName: "v1.2.3",
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 0, "tag exists")
+			},
+			httpStubs: func(reg *httpmock.Registry) {
+				reg.Register(httpmock.GraphQL("RepositoryFindRef"),
+					httpmock.StringResponse(`{"data":{"repository":{"ref": {"id": ""}}}}`))
+			},
+			wantErr: "tag v1.2.3 exists locally but has not been pushed to OWNER/REPO, please push it before continuing or specify the `--target` flag to create a new tag",
+		},
+		{
+			name: "create a release when unpublished local tag and target specified",
+			opts: &CreateOptions{
+				TagName: "v1.2.3",
+				Target:  "main",
+			},
+			askStubs: func(as *prompt.AskStubber) {
+				as.StubPrompt("Title (optional)").AnswerWith("")
+				as.StubPrompt("Release notes").
+					AssertOptions([]string{"Write my own", "Write using generated notes as template", "Write using git tag message as template", "Leave blank"}).
+					AnswerWith("Leave blank")
+				as.StubPrompt("Is this a prerelease?").AnswerWith(false)
+				as.StubPrompt("Submit?").AnswerWith("Publish release")
+			},
+			runStubs: func(rs *run.CommandStubber) {
+				rs.Register(`git tag --list`, 0, "tag exists")
+			},
+			httpStubs: func(reg *httpmock.Registry) {
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases/generate-notes"),
+					httpmock.StatusStringResponse(200, `{
+						"name": "generated name",
+						"body": "generated body"
+					}`))
+				reg.Register(httpmock.REST("POST", "repos/OWNER/REPO/releases"), httpmock.StatusStringResponse(201, `{
+					"url": "https://api.github.com/releases/123",
+					"upload_url": "https://api.github.com/assets/upload",
+					"html_url": "https://github.com/OWNER/REPO/releases/tag/v1.2.3"
+				}`))
+			},
+			wantParams: map[string]interface{}{
+				"draft":            false,
+				"prerelease":       false,
+				"tag_name":         "v1.2.3",
+				"target_commitish": "main",
+			},
+			wantOut: "https://github.com/OWNER/REPO/releases/tag/v1.2.3\n",
+		},
 	}
 	for _, tt := range tests {
 		ios, _, stdout, stderr := iostreams.Test()
@@ -674,13 +850,18 @@ func Test_createRun_interactive(t *testing.T) {
 			return val, nil
 		}
 
-		as, teardown := prompt.InitAskStubber()
-		defer teardown()
-		if tt.askStubs != nil {
-			tt.askStubs(as)
-		}
-
 		t.Run(tt.name, func(t *testing.T) {
+			as := prompt.NewAskStubber(t)
+			if tt.askStubs != nil {
+				tt.askStubs(as)
+			}
+
+			rs, teardown := run.Stub()
+			defer teardown(t)
+			if tt.runStubs != nil {
+				tt.runStubs(rs)
+			}
+
 			err := createRun(tt.opts)
 
 			if tt.wantErr != "" {
@@ -691,7 +872,17 @@ func Test_createRun_interactive(t *testing.T) {
 			}
 
 			if tt.wantParams != nil {
-				bb, err := ioutil.ReadAll(reg.Requests[1].Body)
+				var r *http.Request
+				for _, req := range reg.Requests {
+					if req.URL.Path == "/repos/OWNER/REPO/releases" {
+						r = req
+						break
+					}
+				}
+				if r == nil {
+					t.Fatalf("no http requests for creating a release found")
+				}
+				bb, err := io.ReadAll(r.Body)
 				assert.NoError(t, err)
 				var params map[string]interface{}
 				err = json.Unmarshal(bb, &params)
